@@ -20,7 +20,7 @@ use POE qw(Wheel::SocketFactory Wheel::ReadWrite
 
 use vars qw(@ISA @EXPORT $VERSION $poe_kernel);
 
-$VERSION = '0.12';
+$VERSION = '0.14';
 
 @ISA = qw(Exporter);
 @EXPORT = qw(FTP_PASSIVE FTP_ACTIVE FTP_MANUAL FTP_ASCII FTP_BINARY);
@@ -844,9 +844,9 @@ sub handler_complex_preliminary {
   # sslify the data connection
   my $socket = $heap->{data_rw_wheel}->get_input_handle();
   delete $heap->{data_rw_wheel};
-  eval { $socket = Client_SSLify( $socket, 'tlsv1' )};
-  if ( $@ ) {
-    die "Unable to SSLify data connection: $@";
+  if ( $heap->{tlsdata} ) {
+    eval { $socket = Client_SSLify( $socket, 'tlsv1' )};
+    die "Unable to SSLify data connection: $@" if $@;
   }
 
   # set up the rw wheel again
